@@ -519,8 +519,32 @@ class DocumentDataDuplicateIdError(DocumentError):
         }
 
 
+class DocumentDataViolationError(DocumentError):
+    """Error in response to a request where the request violates a constraint in
+    Postgres.
+    """
+
+    # pylint: disable=too-few-public-methods
+
+    status = 409
+
+    def __init__(self, pointer, detail):
+        super().__init__(pointer)
+        self.detail = detail
+
+    def to_error(self):
+        return {
+            'status': '409',
+            'source': {
+                'pointer': self.pointer,
+            },
+            'title': 'Invalid resource object.',
+            'detail': self.detail,
+        }
+
+
 class DocumentDataInvalidIdError(DocumentError):
-    """Error in response to PATCH /{collection}/id request where the request
+    """Error in response to PATCH /{collection}/{id} request where the request
     document contains a resource object with an invalid id.
     """
 
