@@ -1,4 +1,4 @@
-# Copyright © 2018-2019 Roel van der Goot
+# Copyright © 2018-2020 Roel van der Goot
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -30,6 +30,7 @@ from ajsonapi.errors import (
 from ajsonapi.field import Field
 
 RE_FIELDS = re_compile(r'fields\[([^\]]*)\]')
+RE_PAGE = re_compile(r'page\[([^\]]*)\]')
 
 
 def query_has_parameter(query, name):
@@ -55,6 +56,7 @@ def parse_fields(request_query, query, errors, *, allow=False):
 def fields_dict(request_query, errors):
     """Helper function for parsing request query fields parameters."""
 
+    # pylint: disable=import-outside-toplevel,cyclic-import
     from ajsonapi.uri.collection import Collection
 
     return_dict = {}
@@ -72,7 +74,7 @@ def fields_dict(request_query, errors):
                 continue
             for field_name in values.split(','):
                 try:
-                    field = getattr(collection.table, field_name)
+                    field = getattr(collection.table.___, field_name)
                 except AttributeError:
                     errors.append(
                         FieldsInvalidFieldError(collection_name, field_name))
@@ -85,15 +87,28 @@ def fields_dict(request_query, errors):
     return return_dict
 
 
-def parse_sort(request_query, query, errors):
-    """Parses the request's sort query parameter."""
-    if query_has_parameter(request_query, 'sort'):
-        errors.append(QueryParameterUnsupportedError('sort'))
-    query['sort'] = lambda x: True
-
-
-def parse_page(request_query, query, errors):
+def parse_page(request_query, query, errors, *, allow=False):
     """Parses the request's page query parameter."""
     if query_has_parameter(request_query, 'page'):
-        errors.append(QueryParameterUnsupportedError('page'))
-    query['page'] = None
+        if allow:
+            query['page'] = page_dict(request_query, errors)
+        else:
+            errors.append(QueryParameterUnsupportedError('page'))
+    else:
+        query['page'] = {}
+
+
+def page_dict(request_query, errors):
+    """Helper function for parsing request query page parameters."""
+    # pylint: disable=unused-argument
+
+    return_dict = {}
+    for key, value in request_query.items():
+        match = RE_PAGE.match(key)
+        if match:
+            page_key = match.group(1)
+            if page_key == 'number':
+                return_dict['number'] = int(value)
+            elif page_key == 'size':
+                return_dict['size'] = int(value)
+    return return_dict
