@@ -297,8 +297,10 @@ class OneToOneLocalRelationship(LocalRelationship, ToOneRelationship):
         OneToOneLocalRelationship.
         """
 
-        return (f'UNIQUE ({self.lfkey}),\n   '
-                f'FOREIGN KEY ({self.lfkey}) REFERENCES {self.rtable.name}(id)')
+        return [
+            f'UNIQUE ({self.lfkey})',
+            f'FOREIGN KEY ({self.lfkey}) REFERENCES {self.rtable.name}(id)'
+        ]
 
     def collection_remote_ids(self, query, local_ids=None):
         filters = query['filters']
@@ -1137,7 +1139,7 @@ class ManyToOneRelationship(LocalRelationship, ToOneRelationship):
         ManyToOneRelationship.
         """
 
-        return f'FOREIGN KEY ({self.lfkey}) REFERENCES {self.rtable.name}(id)'
+        return [f'FOREIGN KEY ({self.lfkey}) REFERENCES {self.rtable.name}(id)']
 
     def collection_remote_ids(self, query, local_ids=None):
         filters = query['filters']
@@ -1348,9 +1350,9 @@ class ManyToManyRelationship(ToManyRelationship):
                 async with env.connection.transaction():
                     log.debug(f'{stmt}: {data}')
                     await env.connection.executemany(stmt, data)
-        except ForeignKeyViolationError:
+        except ForeignKeyViolationError as exc:
             env.cancel()
-            raise NonexistentRelationshipIdError()
+            raise NonexistentRelationshipIdError() from exc
 
     async def get_object_data(self, env):
         """Creates the response data member for ManyToManyRelationships.
@@ -1447,9 +1449,9 @@ class ManyToManyRelationship(ToManyRelationship):
                 async with env.connection.transaction():
                     log.debug(f'{stmt}: {data}')
                     await env.connection.executemany(stmt, data)
-        except ForeignKeyViolationError:
+        except ForeignKeyViolationError as exc:
             env.cancel()
-            raise NonexistentRelationshipIdError()
+            raise NonexistentRelationshipIdError() from exc
 
     async def get_to_one_related_data(self, env):
         """Creates the response data member for OneToManyRelationships.
