@@ -55,6 +55,7 @@ class Table:
     # pylint: disable=too-few-public-methods
 
     by_class_name = {}
+    atable_def_by_class_name = {}
 
     @classmethod
     def __init_subclass__(cls):
@@ -133,14 +134,13 @@ class Table:
                                 rclassname = col.rtable
                             else:
                                 rclassname = col.rtable.__name__
-                            cls_def = (
-                                f"class {col.atable}(AssociationTable):\n"
-                                f"    rel0 = ManyToOneRelationship"
-                                f"('{lclassname}', lfkey='{col.lafkey}')\n"
-                                f"    rel1 = ManyToOneRelationship"
-                                f"('{rclassname}', lfkey='{col.rafkey}')\n")
-                            # pylint: disable=exec-used
-                            exec(compile(cls_def, '<string>', 'exec'))
+                            if col.atable not in cls.atable_def_by_class_name:
+                                cls.atable_def_by_class_name[col.atable] = (
+                                    f"class {col.atable}(AssociationTable):\n"
+                                    f"    rel0 = ManyToOneRelationship"
+                                    f"('{lclassname}', lfkey='{col.lafkey}')\n"
+                                    f"    rel1 = ManyToOneRelationship"
+                                    f"('{rclassname}', lfkey='{col.rafkey}')\n")
                 if (isinstance(col.rtable, str) and
                         col.rtable in Table.by_class_name):
                     col.rtable = Table.by_class_name[col.rtable]
@@ -254,6 +254,11 @@ async def create_all(pool):
 
     # pylint: disable=protected-access
     stmts_delayed = []  # Delayed foreign key constraints
+
+    for class_name, stmt in Table.atable_def_by_class_name.items():
+        if class_name not in Table.by_class_name:
+            # pylint: disable=exec-used
+            exec(compile(stmt, '<string>', 'exec'))
     dependencies = {
         table: table._dependencies() for table in Table.by_class_name.values()
     }
