@@ -25,7 +25,14 @@ from asyncio import Event, Lock, create_task, gather
 from itertools import chain
 from re import compile as re_compile
 
-from asyncpg.exceptions import ForeignKeyViolationError, UniqueViolationError
+from asyncpg.exceptions import (
+    CheckViolationError,
+    ExclusionViolationError,
+    ForeignKeyViolationError,
+    NotNullViolationError,
+    RestrictViolationError,
+    UniqueViolationError,
+)
 
 from ajsonapi.conversions import id_number_to_name
 from ajsonapi.document import (
@@ -34,7 +41,6 @@ from ajsonapi.document import (
 )
 from ajsonapi.environments import GetCollectionIncludedEnvironment
 from ajsonapi.errors import (
-    DocumentDataDuplicateIdError,
     FilterInvalidFieldError,
     IncludeInvalidPathError,
     QueryParameterUnsupportedError,
@@ -44,8 +50,12 @@ from ajsonapi.errors import (
 from ajsonapi.events import CreateEvent
 from ajsonapi.exceptions import ErrorsException, NonexistentRelationshipIdError
 from ajsonapi.logging import log
+from ajsonapi.postgres import (
+    convert_unique_violation_error,
+    convert_violation_error,
+)
 from ajsonapi.query import parse_fields, parse_page, query_has_parameter
-from ajsonapi.responses import document_response, no_data_response
+from ajsonapi.responses import document_response, no_content_response
 from ajsonapi.uri.resource import Resource
 
 RE_FILTER = re_compile(r'filter\[([^\]]*)\]')
@@ -204,14 +214,9 @@ class Collection(Resource):
     async def post(self, document, query):
         """Produces the response for a POST /{collection} request."""
 
-        try:
-            if document.id_number:
-                return await self.post_with_id(document, query)
-            return await self.post_without_id(document, query)
-        except UniqueViolationError as exc:
-            raise ErrorsException([
-                DocumentDataDuplicateIdError(f"/data/id/{document.data['id']}")
-            ]) from exc
+        if document.id_number:
+            return await self.post_with_id(document, query)
+        return await self.post_without_id(document, query)
 
     async def post_with_id(self, document, query):
         """Produces the response for a POST /{collection} request where the
@@ -224,7 +229,7 @@ class Collection(Resource):
         await env.run()
         event = CreateEvent(document.data)
         await event.broadcast()
-        return no_data_response()
+        return no_content_response()
 
     async def post_without_id(self, document, query):
         """Produces the response for a POST /{collection} request where the
@@ -272,6 +277,14 @@ class Collection(Resource):
         except ForeignKeyViolationError as exc:
             env.cancel()
             raise NonexistentRelationshipIdError() from exc
+        except UniqueViolationError as exc:
+            env.cancel()
+            raise ErrorsException([convert_unique_violation_error(exc)
+                                  ]) from exc
+        except (CheckViolationError, ExclusionViolationError,
+                NotNullViolationError, RestrictViolationError) as exc:
+            env.cancel()
+            raise ErrorsException([convert_violation_error(exc)]) from exc
 
     async def post_without_id_task(self, env):
         """Updates the database collection table based on the POST
@@ -305,6 +318,11 @@ class Collection(Resource):
         except ForeignKeyViolationError as exc:
             env.cancel()
             raise NonexistentRelationshipIdError() from exc
+        except (CheckViolationError, ExclusionViolationError,
+                NotNullViolationError, RestrictViolationError,
+                UniqueViolationError) as exc:
+            env.cancel()
+            raise ErrorsException([convert_violation_error(exc)]) from exc
 
     async def to_document(self, query=None, links=None):
         """Creates the document for the resource objects in this resource
