@@ -23,7 +23,14 @@
 from asyncio import Event, Lock, create_task, gather
 from itertools import chain
 
-from asyncpg.exceptions import ForeignKeyViolationError
+from asyncpg.exceptions import (
+    CheckViolationError,
+    ExclusionViolationError,
+    ForeignKeyViolationError,
+    NotNullViolationError,
+    RestrictViolationError,
+    UniqueViolationError,
+)
 
 from ajsonapi.conversions import id_number_to_name
 from ajsonapi.document import ResourceObjectDocument
@@ -37,7 +44,8 @@ from ajsonapi.events import DeleteEvent, UpdateEvent
 from ajsonapi.exceptions import ErrorsException, NonexistentRelationshipIdError
 from ajsonapi.id_value import IdValue
 from ajsonapi.logging import log
-from ajsonapi.responses import document_response, no_data_response
+from ajsonapi.postgres import convert_violation_error
+from ajsonapi.responses import document_response, no_content_response
 from ajsonapi.uri.collection import (
     Collection,
     VerifyRelationshipIdsEnvironment,
@@ -101,7 +109,7 @@ class Object(Resource):
             'id': id_number_to_name(self.id.number),
         })
         await event.broadcast()
-        return no_data_response()
+        return no_content_response()
 
     async def patch(self, document, query):
         """Patches the object in the database and produces the response for a
@@ -149,6 +157,11 @@ class Object(Resource):
         except ForeignKeyViolationError as exc:
             env.cancel()
             raise NonexistentRelationshipIdError() from exc
+        except (CheckViolationError, ExclusionViolationError,
+                NotNullViolationError, RestrictViolationError,
+                UniqueViolationError) as exc:
+            env.cancel()
+            raise ErrorsException([convert_violation_error(exc)]) from exc
 
     async def to_document(self, query=None, links=None):
         """Creates the document for this resource object.
