@@ -629,22 +629,24 @@ def make_related_resource(collection_name, id_name, related_resource_name):
 
     try:
         collection = Collection.by_name[collection_name]
-    except KeyError:
-        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')])
+    except KeyError as exc:
+        raise ErrorsException([ResourceNotFoundError(f'/{collection_name}')
+                              ]) from exc
 
     try:
         id_ = IdValue(id_name)
-    except ValueError:
-        raise ErrorsException(
-            [ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')])
+    except ValueError as exc:
+        raise ErrorsException([
+            ResourceNotFoundMalformedIdError(f'/{collection_name}/{id_name}')
+        ]) from exc
 
     try:
         relationship = getattr(collection.table.___, related_resource_name)
-    except AttributeError:
+    except AttributeError as exc:
         raise ErrorsException([
             ResourceNotFoundError(f'/{collection_name}/{id_name}/'
                                   f'{related_resource_name}')
-        ])
+        ]) from exc
 
     return relationship.make_uri_related_resource(related_resource_name,
                                                   collection, id_)
