@@ -47,7 +47,7 @@ from ajsonapi.logging import log
 from ajsonapi.responses import (
     document_response,
     errors_response,
-    no_data_response,
+    no_content_response,
 )
 from ajsonapi.uri.collection import Collection
 from ajsonapi.uri.resource import Resource
@@ -159,6 +159,12 @@ class Relationship(Resource):
         /{collection}/{id}/relationships/{relationship} request.
         """
 
+    @abstractmethod
+    def options(self):
+        """Produces the response for an OPTIONS
+        /{collection}/{id}/relationships/{relationship} request.
+        """
+
     async def verify_id_exists(self, connection):
         """Raises an exception in case the id in the URL does not exist."""
         stmt = f'SELECT FROM {self.table.name} WHERE id=$1'
@@ -204,7 +210,7 @@ class ToOneRelationship(Relationship):
         else:
             data_id = None
         await self.patch_execute(data_id)
-        return no_data_response()
+        return no_content_response()
 
     @abstractmethod
     async def patch_execute(self, data_id):
@@ -219,7 +225,7 @@ class ToOneRelationship(Relationship):
         {relationship} is a to-one relationship.
         """
         return errors_response([MethodNotAllowedError()],
-                               headers={'Allow': 'GET,HEAD,PATCH'})
+                               headers={'Allow': 'GET,HEAD,OPTIONS,PATCH'})
 
     async def delete(self, document, query):
         """Produces the response for a DELETE
@@ -227,7 +233,7 @@ class ToOneRelationship(Relationship):
         {relationship} is a to-one relationship.
         """
         return errors_response([MethodNotAllowedError()],
-                               headers={'Allow': 'GET,HEAD,PATCH'})
+                               headers={'Allow': 'GET,HEAD,OPTIONS,PATCH'})
 
     def put(self):
         """Produces the response for a DELETE
@@ -235,7 +241,15 @@ class ToOneRelationship(Relationship):
         {relationship} is a to-one relationship.
         """
         return errors_response([MethodNotAllowedError()],
-                               headers={'Allow': 'GET,HEAD,PATCH'})
+                               headers={'Allow': 'GET,HEAD,OPTIONS,PATCH'})
+
+    def options(self):
+        """Produces the response for an OPTIONS
+        /{collection}/{id}/relationships/{relationship} request where
+        {relationship} is a to-one relationship.
+        """
+        headers = {'Allow': 'GET,OPTIONS,PATCH'}
+        return no_content_response(headers=headers)
 
 
 class OneToOneLocalRelationship(ToOneRelationship):
@@ -431,7 +445,7 @@ class ToManyRelationship(Relationship):
 
     async def patch(self, document, query):
         await self.patch_execute(document.ids)
-        return no_data_response()
+        return no_content_response()
 
     @abstractmethod
     async def patch_execute(self, data_ids):
@@ -446,7 +460,7 @@ class ToManyRelationship(Relationship):
         {relationship} is a to-many relationship.
         """
         await self.post_execute(document.ids)
-        return no_data_response()
+        return no_content_response()
 
     @abstractmethod
     async def post_execute(self, data_ids):
@@ -461,15 +475,24 @@ class ToManyRelationship(Relationship):
         {relationship} is a to-many relationship.
         """
         await self.delete_execute(document.ids)
-        return no_data_response()
+        return no_content_response()
 
     def put(self):
         """Produces the response for a DELETE
         /{collection}/{id}/relationships/{relationship} request where
         {relationship} is a to-one relationship.
         """
-        return errors_response([MethodNotAllowedError()],
-                               headers={'Allow': 'DELETE,GET,HEAD,PATCH,POST'})
+        return errors_response(
+            [MethodNotAllowedError()],
+            headers={'Allow': 'DELETE,GET,HEAD,OPTIONS,PATCH,POST'})
+
+    def options(self):
+        """Produces the response for an OPTIONS
+        /{collection}/{id}/relationships/{relationship} request where
+        {relationship} is a to-one relationship.
+        """
+        headers = {'Allow': 'DELETE,GET,OPTIONS,PATCH,POST'}
+        return no_content_response(headers=headers)
 
     @abstractmethod
     async def delete_execute(self, data_ids):
